@@ -1,19 +1,7 @@
 /*
- * Copyright 2001 Stefan Schimanski <1Stein@gmx.de>
+ * SPDX-FileCopyrightText: 2001 Stefan Schimanski <1Stein@gmx.de>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef KTIMER_H_INCLUDED
@@ -35,7 +23,11 @@ public:
     explicit KTimerJob(QObject *parent = nullptr);
     ~KTimerJob() override;
 
-    enum States { Stopped, Paused, Started };
+    enum States {
+        Stopped,
+        Paused,
+        Started
+    };
 
     unsigned delay() const;
     QString command() const;
